@@ -44,15 +44,16 @@ The easiest way to do that is to use: 'sl config setup'
 """
 # :license: MIT, see LICENSE for more details.
 
-import sys
 import logging
+import sys
 
-from docopt import docopt, DocoptExit
+import docopt
 
-from SoftLayer import Client, TimedClient, SoftLayerError, SoftLayerAPIError
-from SoftLayer.consts import VERSION
-from .helpers import CLIAbort, ArgumentError, format_output, KeyValueTable
-from .environment import Environment, InvalidCommand, InvalidModule
+import SoftLayer
+from SoftLayer.CLI import environment
+from SoftLayer.CLI import exceptions
+from SoftLayer.CLI import formatting
+from SoftLayer import consts
 
 
 DEBUG_LOGGING_MAP = {
@@ -66,7 +67,7 @@ VALID_FORMATS = ['raw', 'table', 'json']
 
 
 class CommandParser(object):
-    """ Helper class to parse commands
+    """Helper class to parse commands.
 
     :param env: Environment instance
     """
@@ -74,17 +75,17 @@ class CommandParser(object):
         self.env = env
 
     def get_main_help(self):
-        """ Get main help text """
+        """Get main help text."""
         return __doc__.strip()
 
     def get_module_help(self, module_name):
-        """ Get help text for a module """
+        """Get help text for a module."""
         module = self.env.load_module(module_name)
         arg_doc = module.__doc__
         return arg_doc.strip()
 
     def get_command_help(self, module_name, command_name):
-        """ Get help text for a specific command """
+        """Get help text for a specific command."""
         command = self.env.get_command(module_name, command_name)
 
         default_format = 'raw'
@@ -113,35 +114,37 @@ Standard Options:
         return arg_doc.strip()
 
     def parse_main_args(self, args):
-        """ Parse root arguments """
+        """Parse root arguments."""
         main_help = self.get_main_help()
-        arguments = docopt(
+        arguments = docopt.docopt(
             main_help,
-            version=VERSION,
+            version=consts.VERSION,
             argv=args,
             options_first=True)
         arguments['<module>'] = self.env.get_module_name(arguments['<module>'])
         return arguments
 
     def parse_module_args(self, module_name, args):
-        """ Parse module arguments """
+        """Parse module arguments."""
         arg_doc = self.get_module_help(module_name)
-        arguments = docopt(
+        arguments = docopt.docopt(
             arg_doc,
-            version=VERSION,
+            version=consts.VERSION,
             argv=[module_name] + args,
             options_first=True)
         return arguments
 
     def parse_command_args(self, module_name, command_name, args):
-        """ Parse command arguments """
+        """Parse command arguments."""
         command = self.env.get_command(module_name, command_name)
         arg_doc = self.get_command_help(module_name, command_name)
-        arguments = docopt(arg_doc, version=VERSION, argv=[module_name] + args)
+        arguments = docopt.docopt(arg_doc,
+                                  version=consts.VERSION,
+                                  argv=[module_name] + args)
         return command, arguments
 
     def parse(self, args):
-        """ Parse entire tree of arguments """
+        """Parse entire tree of arguments."""
         # handle `sl ...`
         main_args = self.parse_main_args(args)
         module_name = main_args['<module>']
@@ -159,10 +162,8 @@ Standard Options:
             main_args['<args>'])
 
 
-def main(args=sys.argv[1:], env=Environment()):
-    """
-    Entry point for the command-line client.
-    """
+def main(args=sys.argv[1:], env=environment.Environment()):
+    """Entry point for the command-line client."""
     # Parse Top-Level Arguments
     exit_status = 0
     resolver = CommandParser(env)
@@ -182,9 +183,9 @@ def main(args=sys.argv[1:], env=Environment()):
             'config_file': command_args.get('--config')
         }
         if command_args.get('--timings'):
-            client = TimedClient(**kwargs)
+            client = SoftLayer.TimedClient(**kwargs)
         else:
-            client = Client(**kwargs)
+            client = SoftLayer.Client(**kwargs)
 
         # Do the thing
         runnable = command(client=client, env=env)
@@ -192,34 +193,35 @@ def main(args=sys.argv[1:], env=Environment()):
         if data:
             out_format = command_args.get('--format', 'table')
             if out_format not in VALID_FORMATS:
-                raise ArgumentError('Invalid format "%s"' % out_format)
-            output = format_output(data, fmt=out_format)
+                raise exceptions.ArgumentError('Invalid format "%s"'
+                                               % out_format)
+            output = formatting.format_output(data, fmt=out_format)
             if output:
                 env.out(output)
 
         if command_args.get('--timings'):
             out_format = command_args.get('--format', 'table')
             api_calls = client.get_last_calls()
-            timing_table = KeyValueTable(['call', 'time'])
+            timing_table = formatting.KeyValueTable(['call', 'time'])
 
             for call, _, duration in api_calls:
                 timing_table.add_row([call, duration])
 
-            env.err(format_output(timing_table, fmt=out_format))
+            env.err(formatting.format_output(timing_table, fmt=out_format))
 
-    except InvalidCommand as ex:
+    except exceptions.InvalidCommand as ex:
         env.err(resolver.get_module_help(ex.module_name))
         if ex.command_name:
             env.err('')
             env.err(str(ex))
             exit_status = 1
-    except InvalidModule as ex:
+    except exceptions.InvalidModule as ex:
         env.err(resolver.get_main_help())
         if ex.module_name:
             env.err('')
             env.err(str(ex))
         exit_status = 1
-    except DocoptExit as ex:
+    except docopt.DocoptExit as ex:
         env.err(ex.usage)
         env.err(
             '\nUnknown argument(s), use -h or --help for available options')
@@ -227,24 +229,27 @@ def main(args=sys.argv[1:], env=Environment()):
     except KeyboardInterrupt:
         env.out('')
         exit_status = 1
-    except CLIAbort as ex:
+    except exceptions.CLIAbort as ex:
         env.err(str(ex.message))
         exit_status = ex.code
     except SystemExit as ex:
         exit_status = ex.code
-    except SoftLayerAPIError as ex:
+    except SoftLayer.SoftLayerAPIError as ex:
         if 'invalid api token' in ex.faultString.lower():
             env.out("Authentication Failed: To update your credentials, use "
                     "'sl config setup'")
         else:
             env.err(str(ex))
             exit_status = 1
-    except SoftLayerError as ex:
+    except SoftLayer.SoftLayerError as ex:
         env.err(str(ex))
         exit_status = 1
     except Exception:
         import traceback
+        env.err("An unexpected error has occured:")
         env.err(traceback.format_exc())
+        env.err("Feel free to report this error as it is likely a bug:")
+        env.err("    https://github.com/softlayer/softlayer-python/issues")
         exit_status = 1
 
     sys.exit(exit_status)
