@@ -23,21 +23,23 @@ For several commands, <identifier> will be asked for. This can be the id,
 hostname or the ip address for a piece of hardware.
 """
 # :license: MIT, see LICENSE for more details.
-import re
 import os
-from os import linesep
-from SoftLayer.CLI.helpers import (
-    CLIRunnable, Table, KeyValueTable, FormattedItem, NestedDict, CLIAbort,
-    blank, listing, gb, active_txn, no_going_back, resolve_id, confirm,
-    ArgumentError, update_with_template_args, export_to_template)
-from SoftLayer import HardwareManager, SshKeyManager
+import re
+
+import SoftLayer
+from SoftLayer.CLI import environment
+from SoftLayer.CLI import exceptions
+from SoftLayer.CLI import formatting
+from SoftLayer.CLI import helpers
+from SoftLayer.CLI import template
+from SoftLayer import utils
 
 
-class ListServers(CLIRunnable):
+class ListServers(environment.CLIRunnable):
     """
 usage: sl server list [options]
 
-List hardware servers on the acount
+List hardware servers on the account
 
 Examples:
   sl server list --datacenter=dal05
@@ -63,7 +65,7 @@ For more on filters see 'sl help filters'
     action = 'list'
 
     def execute(self, args):
-        manager = HardwareManager(self.client)
+        manager = SoftLayer.HardwareManager(self.client)
 
         tags = None
         if args.get('--tags'):
@@ -78,7 +80,7 @@ For more on filters see 'sl help filters'
             nic_speed=args.get('--network'),
             tags=tags)
 
-        table = Table([
+        table = formatting.Table([
             'id',
             'datacenter',
             'host',
@@ -91,22 +93,22 @@ For more on filters see 'sl help filters'
         table.sortby = args.get('--sortby') or 'host'
 
         for server in servers:
-            server = NestedDict(server)
+            server = utils.NestedDict(server)
             table.add_row([
                 server['id'],
-                server['datacenter']['name'] or blank(),
+                server['datacenter']['name'] or formatting.blank(),
                 server['fullyQualifiedDomainName'],
                 server['processorPhysicalCoreAmount'],
-                gb(server['memoryCapacity'] or 0),
-                server['primaryIpAddress'] or blank(),
-                server['primaryBackendIpAddress'] or blank(),
-                active_txn(server),
+                formatting.gb(server['memoryCapacity'] or 0),
+                server['primaryIpAddress'] or formatting.blank(),
+                server['primaryBackendIpAddress'] or formatting.blank(),
+                formatting.active_txn(server),
             ])
 
         return table
 
 
-class ServerDetails(CLIRunnable):
+class ServerDetails(environment.CLIRunnable):
     """
 usage: sl server detail [--passwords] [--price] <identifier> [options]
 
@@ -119,39 +121,45 @@ Options:
     action = 'detail'
 
     def execute(self, args):
-        hardware = HardwareManager(self.client)
+        hardware = SoftLayer.HardwareManager(self.client)
 
-        table = KeyValueTable(['Name', 'Value'])
+        table = formatting.KeyValueTable(['Name', 'Value'])
         table.align['Name'] = 'r'
         table.align['Value'] = 'l'
 
-        hardware_id = resolve_id(
+        hardware_id = helpers.resolve_id(
             hardware.resolve_ids, args.get('<identifier>'), 'hardware')
         result = hardware.get_hardware(hardware_id)
-        result = NestedDict(result)
+        result = utils.NestedDict(result)
 
         table.add_row(['id', result['id']])
         table.add_row(['hostname', result['fullyQualifiedDomainName']])
         table.add_row(['status', result['hardwareStatus']['status']])
-        table.add_row(['datacenter', result['datacenter']['name'] or blank()])
+        table.add_row(['datacenter',
+                       result['datacenter']['name'] or formatting.blank()])
         table.add_row(['cores', result['processorPhysicalCoreAmount']])
-        table.add_row(['memory', gb(result['memoryCapacity'])])
-        table.add_row(['public_ip', result['primaryIpAddress'] or blank()])
-        table.add_row(
-            ['private_ip', result['primaryBackendIpAddress'] or blank()])
+        table.add_row(['memory',
+                       formatting.gb(result['memoryCapacity'])])
+        table.add_row(['public_ip',
+                       result['primaryIpAddress'] or formatting.blank()])
+        table.add_row(['private_ip',
+                       result['primaryBackendIpAddress']
+                       or formatting.blank()])
         table.add_row(['ipmi_ip',
-                       result['networkManagementIpAddress'] or blank()])
+                       result['networkManagementIpAddress']
+                       or formatting.blank()])
         table.add_row([
             'os',
-            FormattedItem(
+            formatting.FormattedItem(
                 result['operatingSystem']['softwareLicense']
-                ['softwareDescription']['referenceCode'] or blank(),
+                ['softwareDescription']['referenceCode'] or formatting.blank(),
                 result['operatingSystem']['softwareLicense']
-                ['softwareDescription']['name'] or blank()
+                ['softwareDescription']['name'] or formatting.blank()
             )])
-        table.add_row(['created', result['provisionDate'] or blank()])
+        table.add_row(['created',
+                       result['provisionDate'] or formatting.blank()])
 
-        vlan_table = Table(['type', 'number', 'id'])
+        vlan_table = formatting.Table(['type', 'number', 'id'])
         for vlan in result['networkVlans']:
             vlan_table.add_row([
                 vlan['networkSpace'], vlan['vlanNumber'], vlan['id']])
@@ -169,18 +177,19 @@ Options:
             for item in result['operatingSystem']['passwords']:
                 user_strs.append(
                     "%s %s" % (item['username'], item['password']))
-            table.add_row(['users', listing(user_strs)])
+            table.add_row(['users', formatting.listing(user_strs)])
 
         tag_row = []
         for tag in result['tagReferences']:
             tag_row.append(tag['tag']['name'])
 
         if tag_row:
-            table.add_row(['tags', listing(tag_row, separator=',')])
+            table.add_row(['tags', formatting.listing(tag_row, separator=',')])
 
-        if not result['privateNetworkOnlyFlag']:
-            ptr_domains = self.client['Hardware_Server']\
-                .getReverseDomainRecords(id=hardware_id)
+        # Test to see if this actually has a primary (public) ip address
+        if result['primaryIpAddress']:
+            ptr_domains = (self.client['Hardware_Server']
+                           .getReverseDomainRecords(id=hardware_id))
 
             for ptr_domain in ptr_domains:
                 for ptr in ptr_domain['resourceRecords']:
@@ -189,7 +198,7 @@ Options:
         return table
 
 
-class ServerReload(CLIRunnable):
+class ServerReload(environment.CLIRunnable):
     """
 usage: sl server reload <identifier> [--key=KEY...] [options]
 
@@ -206,22 +215,22 @@ Optional:
     options = ['confirm']
 
     def execute(self, args):
-        hardware = HardwareManager(self.client)
-        hardware_id = resolve_id(
+        hardware = SoftLayer.HardwareManager(self.client)
+        hardware_id = helpers.resolve_id(
             hardware.resolve_ids, args.get('<identifier>'), 'hardware')
         keys = []
         if args.get('--key'):
             for key in args.get('--key'):
-                key_id = resolve_id(SshKeyManager(self.client).resolve_ids,
-                                    key, 'SshKey')
+                resolver = SoftLayer.SshKeyManager(self.client).resolve_ids
+                key_id = helpers.resolve_id(resolver, key, 'SshKey')
                 keys.append(key_id)
-        if args['--really'] or no_going_back(hardware_id):
+        if args['--really'] or formatting.no_going_back(hardware_id):
             hardware.reload(hardware_id, args['--postinstall'], keys)
         else:
-            CLIAbort('Aborted')
+            raise exceptions.CLIAbort('Aborted')
 
 
-class CancelServer(CLIRunnable):
+class CancelServer(environment.CLIRunnable):
     """
 usage: sl server cancel <identifier> [options]
 
@@ -237,8 +246,8 @@ Options:
     options = ['confirm']
 
     def execute(self, args):
-        mgr = HardwareManager(self.client)
-        hw_id = resolve_id(
+        mgr = SoftLayer.HardwareManager(self.client)
+        hw_id = helpers.resolve_id(
             mgr.resolve_ids, args.get('<identifier>'), 'hardware')
 
         comment = args.get('--comment')
@@ -248,13 +257,13 @@ Options:
 
         reason = args.get('--reason')
 
-        if args['--really'] or no_going_back(hw_id):
+        if args['--really'] or formatting.no_going_back(hw_id):
             mgr.cancel_hardware(hw_id, reason, comment)
         else:
-            CLIAbort('Aborted')
+            raise exceptions.CLIAbort('Aborted')
 
 
-class ServerCancelReasons(CLIRunnable):
+class ServerCancelReasons(environment.CLIRunnable):
     """
 usage: sl server cancel-reasons
 
@@ -264,11 +273,11 @@ Display a list of cancellation reasons
     action = 'cancel-reasons'
 
     def execute(self, args):
-        table = Table(['Code', 'Reason'])
+        table = formatting.Table(['Code', 'Reason'])
         table.align['Code'] = 'r'
         table.align['Reason'] = 'l'
 
-        mgr = HardwareManager(self.client)
+        mgr = SoftLayer.HardwareManager(self.client)
 
         for code, reason in mgr.get_cancellation_reasons().items():
             table.add_row([code, reason])
@@ -276,7 +285,7 @@ Display a list of cancellation reasons
         return table
 
 
-class ServerPowerOff(CLIRunnable):
+class ServerPowerOff(environment.CLIRunnable):
     """
 usage: sl server power-off <identifier> [options]
 
@@ -286,17 +295,19 @@ Power off an active server
     options = ['confirm']
 
     def execute(self, args):
-        mgr = HardwareManager(self.client)
-        hw_id = resolve_id(mgr.resolve_ids, args.get('<identifier>'),
-                           'hardware')
-        if args['--really'] or confirm('This will power off the server with '
-                                       'id %s. Continue?' % hw_id):
+        mgr = SoftLayer.HardwareManager(self.client)
+        hw_id = helpers.resolve_id(mgr.resolve_ids,
+                                   args.get('<identifier>'),
+                                   'hardware')
+        if args['--really'] or formatting.confirm('This will power off the '
+                                                  'server with id %s '
+                                                  'Continue?' % hw_id):
             self.client['Hardware_Server'].powerOff(id=hw_id)
         else:
-            raise CLIAbort('Aborted.')
+            raise exceptions.CLIAbort('Aborted.')
 
 
-class ServerReboot(CLIRunnable):
+class ServerReboot(environment.CLIRunnable):
     """
 usage: sl server reboot <identifier> [--hard | --soft] [options]
 
@@ -311,11 +322,13 @@ Optional:
 
     def execute(self, args):
         hardware_server = self.client['Hardware_Server']
-        mgr = HardwareManager(self.client)
-        hw_id = resolve_id(mgr.resolve_ids, args.get('<identifier>'),
-                           'hardware')
-        if args['--really'] or confirm('This will power off the server with '
-                                       'id %s. Continue?' % hw_id):
+        mgr = SoftLayer.HardwareManager(self.client)
+        hw_id = helpers.resolve_id(mgr.resolve_ids,
+                                   args.get('<identifier>'),
+                                   'hardware')
+        if args['--really'] or formatting.confirm('This will power off the '
+                                                  'server with id %s. '
+                                                  'Continue?' % hw_id):
             if args['--hard']:
                 hardware_server.rebootHard(id=hw_id)
             elif args['--soft']:
@@ -323,10 +336,10 @@ Optional:
             else:
                 hardware_server.rebootDefault(id=hw_id)
         else:
-            raise CLIAbort('Aborted.')
+            raise exceptions.CLIAbort('Aborted.')
 
 
-class ServerPowerOn(CLIRunnable):
+class ServerPowerOn(environment.CLIRunnable):
     """
 usage: sl server power-on <identifier> [options]
 
@@ -335,13 +348,14 @@ Power on a server
     action = 'power-on'
 
     def execute(self, args):
-        mgr = HardwareManager(self.client)
-        hw_id = resolve_id(mgr.resolve_ids, args.get('<identifier>'),
-                           'hardware')
+        mgr = SoftLayer.HardwareManager(self.client)
+        hw_id = helpers.resolve_id(mgr.resolve_ids,
+                                   args.get('<identifier>'),
+                                   'hardware')
         self.client['Hardware_Server'].powerOn(id=hw_id)
 
 
-class ServerPowerCycle(CLIRunnable):
+class ServerPowerCycle(environment.CLIRunnable):
     """
 usage: sl server power-cycle <identifier> [options]
 
@@ -351,18 +365,20 @@ Issues power cycle to server via the power strip
     options = ['confirm']
 
     def execute(self, args):
-        mgr = HardwareManager(self.client)
-        hw_id = resolve_id(mgr.resolve_ids, args.get('<identifier>'),
-                           'hardware')
+        mgr = SoftLayer.HardwareManager(self.client)
+        hw_id = helpers.resolve_id(mgr.resolve_ids,
+                                   args.get('<identifier>'),
+                                   'hardware')
 
-        if args['--really'] or confirm('This will power off the server with '
-                                       'id %s. Continue?' % hw_id):
+        if args['--really'] or formatting.confirm('This will power off the '
+                                                  'server with id %s. '
+                                                  'Continue?' % hw_id):
             self.client['Hardware_Server'].powerCycle(id=hw_id)
         else:
-            raise CLIAbort('Aborted.')
+            raise exceptions.CLIAbort('Aborted.')
 
 
-class NicEditServer(CLIRunnable):
+class NicEditServer(environment.CLIRunnable):
     """
 usage: sl server nic-edit <identifier> (public | private) --speed=SPEED
                           [options]
@@ -378,14 +394,15 @@ Options:
     def execute(self, args):
         public = args['public']
 
-        mgr = HardwareManager(self.client)
-        hw_id = resolve_id(mgr.resolve_ids, args.get('<identifier>'),
-                           'hardware')
+        mgr = SoftLayer.HardwareManager(self.client)
+        hw_id = helpers.resolve_id(mgr.resolve_ids,
+                                   args.get('<identifier>'),
+                                   'hardware')
 
         mgr.change_port_speed(hw_id, public, args['--speed'])
 
 
-class ListChassisServer(CLIRunnable):
+class ListChassisServer(environment.CLIRunnable):
     """
 usage: sl server list-chassis [options]
 
@@ -394,11 +411,11 @@ Display a list of chassis available for ordering dedicated servers.
     action = 'list-chassis'
 
     def execute(self, args):
-        table = Table(['Code', 'Chassis'])
+        table = formatting.Table(['Code', 'Chassis'])
         table.align['Code'] = 'r'
         table.align['Chassis'] = 'l'
 
-        mgr = HardwareManager(self.client)
+        mgr = SoftLayer.HardwareManager(self.client)
         chassis = mgr.get_available_dedicated_server_packages()
 
         for chassis in chassis:
@@ -407,7 +424,7 @@ Display a list of chassis available for ordering dedicated servers.
         return table
 
 
-class ServerCreateOptions(CLIRunnable):
+class ServerCreateOptions(environment.CLIRunnable):
     """
 usage: sl server create-options <chassis_id> [options]
 
@@ -430,9 +447,9 @@ Options:
                'controller']
 
     def execute(self, args):
-        mgr = HardwareManager(self.client)
+        mgr = SoftLayer.HardwareManager(self.client)
 
-        table = KeyValueTable(['Name', 'Value'])
+        table = formatting.KeyValueTable(['Name', 'Value'])
         table.align['Name'] = 'r'
         table.align['Value'] = 'l'
 
@@ -445,7 +462,7 @@ Options:
                 break
 
         if not found:
-            raise CLIAbort('Invalid chassis specified.')
+            raise exceptions.CLIAbort('Invalid chassis specified.')
 
         ds_options = mgr.get_dedicated_server_create_options(chassis_id)
 
@@ -466,12 +483,12 @@ Options:
         if args['--datacenter'] or show_all:
             results = self.get_create_options(ds_options, 'datacenter')[0]
 
-            table.add_row([results[0], listing(sorted(results[1]))])
+            table.add_row([results[0], formatting.listing(sorted(results[1]))])
 
         if (args['--cpu'] or show_all) and not bmc:
             results = self.get_create_options(ds_options, 'cpu')
 
-            cpu_table = Table(['ID', 'Description'])
+            cpu_table = formatting.Table(['ID', 'Description'])
             cpu_table.align['ID'] = 'r'
             cpu_table.align['Description'] = 'l'
 
@@ -482,16 +499,16 @@ Options:
         if (args['--memory'] or show_all) and not bmc:
             results = self.get_create_options(ds_options, 'memory')[0]
 
-            table.add_row([results[0], listing(
+            table.add_row([results[0], formatting.listing(
                 item[0] for item in sorted(results[1]))])
 
         if bmc and (show_all or args['--memory'] or args['--cpu']):
             results = self.get_create_options(ds_options, 'server_core')
-            memory_cpu_table = Table(['memory', 'cpu'])
+            memory_cpu_table = formatting.Table(['memory', 'cpu'])
             for result in results:
                 memory_cpu_table.add_row([
                     result[0],
-                    listing(
+                    formatting.listing(
                         [item[0] for item in sorted(
                             result[1], key=lambda x: int(x[0])
                         )])])
@@ -503,9 +520,9 @@ Options:
             for result in results:
                 table.add_row([
                     result[0],
-                    listing(
+                    formatting.listing(
                         [item[0] for item in sorted(result[1])],
-                        separator=linesep
+                        separator=os.linesep
                     )])
 
         if args['--disk'] or show_all:
@@ -513,22 +530,22 @@ Options:
 
             table.add_row([
                 results[0],
-                listing(
+                formatting.listing(
                     [item[0] for item in sorted(results[1])],
-                    separator=linesep
+                    separator=os.linesep
                 )])
 
         if args['--nic'] or show_all:
             results = self.get_create_options(ds_options, 'nic')
 
             for result in results:
-                table.add_row([result[0], listing(
+                table.add_row([result[0], formatting.listing(
                     item[0] for item in sorted(result[1],))])
 
         if (args['--controller'] or show_all) and not bmc:
             results = self.get_create_options(ds_options, 'disk_controller')[0]
 
-            table.add_row([results[0], listing(
+            table.add_row([results[0], formatting.listing(
                 item[0] for item in sorted(results[1],))])
 
         return table
@@ -567,8 +584,8 @@ Options:
                 ram.append((int(option['capacity']), option['price_id']))
 
             return_value = [('memory', ram)]
-        elif 'server_core' == section and \
-             'server_core' in ds_options['categories']:
+        elif ('server_core' == section
+              and 'server_core' in ds_options['categories']):
             mem_options = {}
             cpu_regex = re.compile(r'(\d+) x ')
             memory_regex = re.compile(r' - (\d+) GB Ram', re.I)
@@ -607,6 +624,11 @@ Options:
                     os_code = self._generate_windows_code(opsys['description'])
                 else:
                     os_results = os_regex.search(opsys['description'])
+
+                    # Skip this operating system if it's not parsable
+                    if os_results is None:
+                        continue
+
                     name = os_results.group(1)
                     version = os_results.group(2)
                     bits = bit_regex.search(opsys['description'])
@@ -734,7 +756,7 @@ Options:
         return os_code
 
 
-class CreateServer(CLIRunnable):
+class CreateServer(environment.CLIRunnable):
     """
 usage: sl server create [--disk=SIZE...] [--key=KEY...] [options]
 
@@ -763,7 +785,7 @@ Optional:
   -i, --postinstall=URI  Post-install script to download
   -k KEY, --key=KEY      SSH keys to assign to the root user. Can be specified
                            multiple times.
-  --dry-run, --test      Do not create the server, just get a quote
+  --test                 Do not create the server, just get a quote
   --vlan_public=VLAN     The ID of the public VLAN on which you want the
                            hardware placed
   --vlan_private=VLAN    The ID of the private VLAN on which you want the
@@ -778,17 +800,8 @@ Optional:
                        '--memory', '--os']
 
     def execute(self, args):
-        update_with_template_args(args)
-        mgr = HardwareManager(self.client)
-
-        # Disks will be a comma-separated list. Let's make it a real list.
-        if isinstance(args.get('--disk'), str):
-            args['--disk'] = args.get('--disk').split(',')
-
-        # Do the same thing for SSH keys
-        if isinstance(args.get('--key'), str):
-            args['--key'] = args.get('--key').split(',')
-
+        template.update_with_template_args(args, list_args=['--disk', '--key'])
+        mgr = SoftLayer.HardwareManager(self.client)
         self._validate_args(args)
 
         ds_options = mgr.get_dedicated_server_create_options(args['--chassis'])
@@ -802,7 +815,7 @@ Optional:
         if args.get('--test'):
             result = mgr.verify_order(**order)
 
-            table = Table(['Item', 'cost'])
+            table = formatting.Table(['Item', 'cost'])
             table.align['Item'] = 'r'
             table.align['cost'] = 'r'
 
@@ -816,31 +829,31 @@ Optional:
             table.add_row(['Total monthly cost', "%.2f" % total])
             output = []
             output.append(table)
-            output.append(FormattedItem(
+            output.append(formatting.FormattedItem(
                 '',
                 ' -- ! Prices reflected here are retail and do not '
-                'take account level discounts and are not guaranteed.')
-            )
+                'take account level discounts and are not guaranteed.'))
 
         if args['--export']:
             export_file = args.pop('--export')
-            export_to_template(export_file, args, exclude=['--wait', '--test'])
+            template.export_to_template(export_file, args,
+                                        exclude=['--wait', '--test'])
             return 'Successfully exported options to a template file.'
 
         if do_create:
-            if args['--really'] or confirm(
+            if args['--really'] or formatting.confirm(
                     "This action will incur charges on your account. "
                     "Continue?"):
                 result = mgr.place_order(**order)
 
-                table = KeyValueTable(['name', 'value'])
+                table = formatting.KeyValueTable(['name', 'value'])
                 table.align['name'] = 'r'
                 table.align['value'] = 'l'
                 table.add_row(['id', result['orderId']])
                 table.add_row(['created', result['orderDate']])
                 output = table
             else:
-                raise CLIAbort('Aborting dedicated server order.')
+                raise exceptions.CLIAbort('Aborting dedicated server order.')
 
         return output
 
@@ -849,7 +862,7 @@ Optional:
         Helper method to centralize argument processing without convoluting
         code flow of the main execute method.
         """
-        mgr = HardwareManager(self.client)
+        mgr = SoftLayer.HardwareManager(self.client)
 
         order = {
             'hostname': args['--hostname'],
@@ -870,7 +883,7 @@ Optional:
         if os_price:
             order['os'] = os_price
         else:
-            raise CLIAbort('Invalid operating system specified.')
+            raise exceptions.CLIAbort('Invalid operating system specified.')
 
         order['location'] = args['--datacenter'] or 'FIRST_AVAILABLE'
 
@@ -921,7 +934,7 @@ Optional:
         if nic_price:
             order['port_speed'] = nic_price
         else:
-            raise CLIAbort('Invalid NIC speed specified.')
+            raise exceptions.CLIAbort('Invalid NIC speed specified.')
 
         if args.get('--postinstall'):
             order['post_uri'] = args.get('--postinstall')
@@ -930,8 +943,8 @@ Optional:
         if args.get('--key'):
             keys = []
             for key in args.get('--key'):
-                key_id = resolve_id(SshKeyManager(self.client).resolve_ids,
-                                    key, 'SshKey')
+                resolver = SoftLayer.SshKeyManager(self.client).resolve_ids
+                key_id = helpers.resolve_id(resolver, key, 'SshKey')
                 keys.append(key_id)
             order['ssh_keys'] = keys
 
@@ -947,8 +960,8 @@ Optional:
         """ Raises an ArgumentError if the given arguments are not valid """
         invalid_args = [k for k in self.required_params if args.get(k) is None]
         if invalid_args:
-            raise ArgumentError('Missing required options: %s'
-                                % ','.join(invalid_args))
+            raise exceptions.ArgumentError('Missing required options: %s'
+                                           % ','.join(invalid_args))
 
     def _get_default_value(self, ds_options, option):
         """ Returns a 'free' price id given an option """
@@ -1007,7 +1020,7 @@ Optional:
                     return item_options[2]
 
 
-class EditServer(CLIRunnable):
+class EditServer(environment.CLIRunnable):
     """
 usage: sl server edit <identifier> [options]
 
@@ -1025,11 +1038,11 @@ Options:
         data = {}
 
         if args['--userdata'] and args['--userfile']:
-            raise ArgumentError('[-u | --userdata] not allowed with '
-                                '[-F | --userfile]')
+            raise exceptions.ArgumentError(
+                '[-u | --userdata] not allowed with [-F | --userfile]')
         if args['--userfile']:
             if not os.path.exists(args['--userfile']):
-                raise ArgumentError(
+                raise exceptions.ArgumentError(
                     'File does not exist [-u | --userfile] = %s'
                     % args['--userfile'])
 
@@ -1042,8 +1055,9 @@ Options:
         data['hostname'] = args.get('--hostname')
         data['domain'] = args.get('--domain')
 
-        mgr = HardwareManager(self.client)
-        hw_id = resolve_id(mgr.resolve_ids, args.get('<identifier>'),
-                           'hardware')
+        mgr = SoftLayer.HardwareManager(self.client)
+        hw_id = helpers.resolve_id(mgr.resolve_ids,
+                                   args.get('<identifier>'),
+                                   'hardware')
         if not mgr.edit(hw_id, **data):
-            raise CLIAbort("Failed to update hardware")
+            raise exceptions.CLIAbort("Failed to update hardware")
