@@ -8,21 +8,30 @@
 # Invalid names are ignored due to long method names and short argument names
 # pylint: disable=C0103
 import socket
-from SoftLayer.utils import NestedDict, query_filter, IdentifierMixin
+
+from SoftLayer.managers import ordering
+from SoftLayer import utils
 
 
-class HardwareManager(IdentifierMixin, object):
+class HardwareManager(utils.IdentifierMixin, object):
     """
     Manages hardware devices.
 
     :param SoftLayer.API.Client client: an API client instance
+    :param SoftLayer.managers.OrderingManager ordering_manager: an optional
+                                              manager to handle ordering.
+                                              If none is provided, one will be
+                                              auto initialized.
     """
-
-    def __init__(self, client):
+    def __init__(self, client, ordering_manager=None):
         self.client = client
         self.hardware = self.client['Hardware_Server']
         self.account = self.client['Account']
         self.resolvers = [self._get_ids_from_ip, self._get_ids_from_hostname]
+        if ordering_manager is None:
+            self.ordering_manager = ordering.OrderingManager(client)
+        else:
+            self.ordering_manager = ordering_manager
 
     def cancel_hardware(self, hardware_id, reason='unneeded', comment=''):
         """ Cancels the specified dedicated server.
@@ -100,7 +109,7 @@ class HardwareManager(IdentifierMixin, object):
 
         """
         if 'mask' not in kwargs:
-            hw_items = set([
+            hw_items = [
                 'id',
                 'hostname',
                 'domain',
@@ -112,17 +121,16 @@ class HardwareManager(IdentifierMixin, object):
                 'primaryBackendIpAddress',
                 'primaryIpAddress',
                 'datacenter',
-            ])
-            server_items = set([
+            ]
+            server_items = [
                 'activeTransaction[id, transactionStatus[friendlyName,name]]',
-            ])
+            ]
 
-            kwargs['mask'] = '[mask[%s],' \
-                             ' mask(SoftLayer_Hardware_Server)[%s]]' % \
-                             (','.join(hw_items),
-                              ','.join(server_items))
+            kwargs['mask'] = ('[mask[%s],'
+                              ' mask(SoftLayer_Hardware_Server)[%s]]'
+                              % (','.join(hw_items), ','.join(server_items)))
 
-        _filter = NestedDict(kwargs.get('filter') or {})
+        _filter = utils.NestedDict(kwargs.get('filter') or {})
         if tags:
             _filter['hardware']['tagReferences']['tag']['name'] = {
                 'operation': 'in',
@@ -130,33 +138,33 @@ class HardwareManager(IdentifierMixin, object):
             }
 
         if cpus:
-            _filter['hardware']['processorPhysicalCoreAmount'] = \
-                query_filter(cpus)
+            _filter['hardware']['processorPhysicalCoreAmount'] = (
+                utils.query_filter(cpus))
 
         if memory:
-            _filter['hardware']['memoryCapacity'] = query_filter(memory)
+            _filter['hardware']['memoryCapacity'] = utils.query_filter(memory)
 
         if hostname:
-            _filter['hardware']['hostname'] = query_filter(hostname)
+            _filter['hardware']['hostname'] = utils.query_filter(hostname)
 
         if domain:
-            _filter['hardware']['domain'] = query_filter(domain)
+            _filter['hardware']['domain'] = utils.query_filter(domain)
 
         if datacenter:
-            _filter['hardware']['datacenter']['name'] = \
-                query_filter(datacenter)
+            _filter['hardware']['datacenter']['name'] = (
+                utils.query_filter(datacenter))
 
         if nic_speed:
-            _filter['hardware']['networkComponents']['maxSpeed'] = \
-                query_filter(nic_speed)
+            _filter['hardware']['networkComponents']['maxSpeed'] = (
+                utils.query_filter(nic_speed))
 
         if public_ip:
-            _filter['hardware']['primaryIpAddress'] = \
-                query_filter(public_ip)
+            _filter['hardware']['primaryIpAddress'] = (
+                utils.query_filter(public_ip))
 
         if private_ip:
-            _filter['hardware']['primaryBackendIpAddress'] = \
-                query_filter(private_ip)
+            _filter['hardware']['primaryBackendIpAddress'] = (
+                utils.query_filter(private_ip))
 
         kwargs['filter'] = _filter.to_dict()
         return self.account.getHardware(**kwargs)
@@ -185,17 +193,11 @@ class HardwareManager(IdentifierMixin, object):
 
     def get_bare_metal_package_id(self):
         """ Return the bare metal package id """
-        packages = self.client['Product_Package'].getAllObjects(
-            mask='mask[id, name]',
-            filter={'name': query_filter('Bare Metal Instance')})
+        ordering_manager = self.ordering_manager
+        mask = "mask[id,name,description,type[keyName]]"
+        package = ordering_manager.get_package_by_type('BARE_METAL_CORE', mask)
 
-        hw_id = 0
-        for package in packages:
-            if 'Bare Metal Instance' == package['name']:
-                hw_id = package['id']
-                break
-
-        return hw_id
+        return package['id']
 
     def get_available_dedicated_server_packages(self):
         """ Retrieves a list of packages that are available for ordering
@@ -204,33 +206,26 @@ class HardwareManager(IdentifierMixin, object):
         :returns: A list of tuples of available dedicated server packages in
                   the form (id, name, description)
         """
+        available_packages = []
+        ordering_manager = self.ordering_manager
 
-        package_obj = self.client['Product_Package']
-        packages = []
+        mask = 'id,name,description,type,isActive'
+        package_types = ['BARE_METAL_CPU', 'BARE_METAL_CORE']
 
-        # Pull back only server packages
-        mask = 'id,name,description,type'
-        _filter = {
-            'type': {
-                'keyName': {
-                    'operation': 'in',
-                    'options': [
-                        {'name': 'data',
-                         'value': ['BARE_METAL_CPU', 'BARE_METAL_CORE']}
-                    ],
-                },
-            },
-        }
+        packages = ordering_manager.get_packages_of_type(package_types,
+                                                         mask)
+        # We only want packages that are active (we can place new orders for)
+        # and non-outlet.
+        # Outlet packages require specialized logic and we don't want to deal
+        # with them right now.
+        packages = ordering_manager.get_only_active_packages(packages)
+        packages = ordering_manager.filter_outlet_packages(packages)
 
-        for package in package_obj.getAllObjects(mask=mask, filter=_filter):
-            # Filter out packages without a name or that are designated as
-            # 'OUTLET.' The outlet packages are missing some necessary data
-            # and their orders will fail.
-            if package.get('name') and 'OUTLET' not in package['description']:
-                packages.append((package['id'], package['name'],
-                                 package['description']))
+        for package in packages:
+            available_packages.append((package['id'], package['name'],
+                                       package['description']))
 
-        return packages
+        return available_packages
 
     def get_dedicated_server_create_options(self, package_id):
         """ Retrieves the available options for creating a dedicated server in
@@ -263,7 +258,7 @@ class HardwareManager(IdentifierMixin, object):
         """
 
         if 'mask' not in kwargs:
-            items = set([
+            items = [
                 'id',
                 'globalIdentifier',
                 'fullyQualifiedDomainName',
@@ -280,21 +275,23 @@ class HardwareManager(IdentifierMixin, object):
                 'networkManagementIpAddress',
                 'userData',
                 'datacenter',
-                'networkComponents[id, status, speed, maxSpeed, name,'
-                'ipmiMacAddress, ipmiIpAddress, macAddress, primaryIpAddress,'
-                'port, primarySubnet]',
-                'networkComponents.primarySubnet[id, netmask,'
-                'broadcastAddress, networkIdentifier, gateway]',
+                '''networkComponents[id, status, speed, maxSpeed, name,
+                   ipmiMacAddress, ipmiIpAddress, macAddress, primaryIpAddress,
+                   port, primarySubnet[id, netmask, broadcastAddress,
+                                       networkIdentifier, gateway]]''',
                 'hardwareChassis[id,name]',
                 'activeTransaction[id, transactionStatus[friendlyName,name]]',
-                'operatingSystem.softwareLicense.'
-                'softwareDescription[manufacturer,name,version,referenceCode]',
-                'operatingSystem.passwords[username,password]',
+                '''operatingSystem[
+                    softwareLicense[softwareDescription[manufacturer,
+                                                        name,
+                                                        version,
+                                                        referenceCode]],
+                    passwords[username,password]]''',
                 'billingItem.recurringFee',
                 'hourlyBillingFlag',
                 'tagReferences[id,tag[name,id]]',
                 'networkVlans[id,vlanNumber,networkSpace]',
-            ])
+            ]
             kwargs['mask'] = "mask[%s]" % ','.join(items)
 
         return self.hardware.getObject(id=hardware_id, **kwargs)
@@ -671,7 +668,7 @@ class HardwareManager(IdentifierMixin, object):
 
         for config in package.getConfiguration(id=package_id, mask=mask):
             code = config['itemCategory']['categoryCode']
-            group = NestedDict(config['itemCategory']) or {}
+            group = utils.NestedDict(config['itemCategory']) or {}
             category = {
                 'sort': config['sort'],
                 'step': config['orderStepId'],
@@ -718,7 +715,7 @@ class HardwareManager(IdentifierMixin, object):
         :param string userdata: user data on the hardware to edit.
                                 If none exist it will be created
         :param string hostname: valid hostname
-        :param string domain: valid domain namem
+        :param string domain: valid domain name
         :param string notes: notes about this particular hardware
 
         """
