@@ -7,8 +7,6 @@
 
     :license: MIT, see LICENSE for more details.
 """
-from SoftLayer.tests import unittest, FixtureClient
-from mock import Mock, patch
 try:
     # Python 3.x compatibility
     import builtins  # NOQA
@@ -16,15 +14,20 @@ try:
 except ImportError:
     builtins_name = '__builtin__'
 
-from SoftLayer.CLI.helpers import format_output, CLIAbort, ArgumentError
+import mock
+
+from SoftLayer.CLI import exceptions
+from SoftLayer.CLI import formatting
 from SoftLayer.CLI.modules import server
+from SoftLayer import testing
+from SoftLayer.testing import fixtures
 
 
-class ServerCLITests(unittest.TestCase):
-    def setUp(self):
-        self.client = FixtureClient()
+class ServerCLITests(testing.TestCase):
+    def set_up(self):
+        self.client = testing.FixtureClient()
 
-    def test_ServerCancelReasons(self):
+    def test_server_cancel_reasons(self):
         runnable = server.ServerCancelReasons(client=self.client)
         output = runnable.execute({})
 
@@ -50,10 +53,11 @@ class ServerCLITests(unittest.TestCase):
             method = 'assertCountEqual'
 
         f = getattr(self, method)
-        f(expected, format_output(output, 'python'))
+        f(expected, formatting.format_output(output, 'python'))
 
-    @patch('SoftLayer.HardwareManager.get_available_dedicated_server_packages')
-    def test_ServerCreateOptions(self, packages):
+    @mock.patch('SoftLayer.HardwareManager'
+                '.get_available_dedicated_server_packages')
+    def test_server_create_options(self, packages):
         args = {
             '<chassis_id>': '999',
             '--all': True,
@@ -97,10 +101,11 @@ class ServerCLITests(unittest.TestCase):
                 'WIN_2012-DC-HYPERV_64'],
             'single nic': ['100', '1000']}
 
-        self.assertEqual(expected, format_output(output, 'python'))
+        self.assertEqual(expected, formatting.format_output(output, 'python'))
 
-    @patch('SoftLayer.HardwareManager.get_available_dedicated_server_packages')
-    def test_ServerCreateOptions_with_cpu_only(self, packages):
+    @mock.patch('SoftLayer.HardwareManager'
+                '.get_available_dedicated_server_packages')
+    def test_server_create_options_with_cpu_only(self, packages):
         args = {
             '<chassis_id>': '999',
             '--all': False,
@@ -131,10 +136,11 @@ class ServerCLITests(unittest.TestCase):
             ],
         }
 
-        self.assertEqual(expected, format_output(output, 'python'))
+        self.assertEqual(expected, formatting.format_output(output, 'python'))
 
-    @patch('SoftLayer.HardwareManager.get_available_dedicated_server_packages')
-    def test_ServerCreateOptions_with_invalid_chassis(self, packages):
+    @mock.patch('SoftLayer.HardwareManager'
+                '.get_available_dedicated_server_packages')
+    def test_server_create_options_with_invalid_chassis(self, packages):
         args = {
             '<chassis_id>': '999',
             '--all': True,
@@ -154,11 +160,12 @@ class ServerCLITests(unittest.TestCase):
 
         runnable = server.ServerCreateOptions(client=self.client)
 
-        self.assertRaises(CLIAbort, runnable.execute, args)
+        self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
-    @patch('SoftLayer.HardwareManager.get_available_dedicated_server_packages')
-    @patch('SoftLayer.HardwareManager.get_bare_metal_package_id')
-    def test_ServerCreateOptions_for_bmc(self, bmpi, packages):
+    @mock.patch('SoftLayer.HardwareManager'
+                '.get_available_dedicated_server_packages')
+    @mock.patch('SoftLayer.HardwareManager.get_bare_metal_package_id')
+    def test_server_create_options_for_bmc(self, bmpi, packages):
         args = {
             '<chassis_id>': '1099',
             '--all': True,
@@ -201,14 +208,12 @@ class ServerCLITests(unittest.TestCase):
                 'WIN_2012-DC-HYPERV_64'],
             'single nic': ['100', '1000']}
 
-        self.assertEqual(expected, format_output(output, 'python'))
-
-    def test_ServerDetails(self):
-        hw_id = 1234
+        self.assertEqual(expected, formatting.format_output(output, 'python'))
 
+    def test_server_details(self):
         runnable = server.ServerDetails(client=self.client)
 
-        args = {'<identifier>': hw_id, '--passwords': True, '--price': True}
+        args = {'<identifier>': 1234, '--passwords': True, '--price': True}
         output = runnable.execute(args)
 
         expected = {
@@ -232,9 +237,22 @@ class ServerCLITests(unittest.TestCase):
                       {'id': 19082, 'number': 3672, 'type': 'PUBLIC'}]
         }
 
-        self.assertEqual(expected, format_output(output, 'python'))
+        self.assertEqual(expected, formatting.format_output(output, 'python'))
 
-    def test_ListServers(self):
+    def test_server_details_issue_332(self):
+        runnable = server.ServerDetails(client=self.client)
+        result = fixtures.Hardware_Server.getObject.copy()
+        result['primaryIpAddress'] = None
+        self.client['Hardware_Server'].getObject.return_value = result
+
+        runnable.execute({'<identifier>': 1234,
+                          '--passwords': True,
+                          '--price': True})
+
+        self.assertFalse(self.client['Hardware_Server']
+                         .getReverseDomainRecords.called)
+
+    def test_list_servers(self):
         runnable = server.ListServers(client=self.client)
 
         output = runnable.execute({'--tags': 'openstack'})
@@ -272,14 +290,12 @@ class ServerCLITests(unittest.TestCase):
             }
         ]
 
-        self.assertEqual(expected, format_output(output, 'python'))
+        self.assertEqual(expected, formatting.format_output(output, 'python'))
 
-    @patch('SoftLayer.CLI.modules.server.CLIAbort')
-    @patch('SoftLayer.CLI.modules.server.no_going_back')
-    @patch('SoftLayer.HardwareManager.reload')
-    @patch('SoftLayer.CLI.modules.server.resolve_id')
-    def test_ServerReload(
-            self, resolve_mock, reload_mock, ngb_mock, abort_mock):
+    @mock.patch('SoftLayer.CLI.formatting.no_going_back')
+    @mock.patch('SoftLayer.HardwareManager.reload')
+    @mock.patch('SoftLayer.CLI.helpers.resolve_id')
+    def test_server_reload(self, resolve_mock, reload_mock, ngb_mock):
         hw_id = 12345
         resolve_mock.return_value = hw_id
         ngb_mock.return_value = False
@@ -294,15 +310,12 @@ class ServerCLITests(unittest.TestCase):
         # Now check to make sure we properly call CLIAbort in the negative case
         args['--really'] = False
 
-        runnable.execute(args)
-        abort_mock.assert_called()
+        self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
-    @patch('SoftLayer.CLI.modules.server.CLIAbort')
-    @patch('SoftLayer.CLI.modules.server.no_going_back')
-    @patch('SoftLayer.HardwareManager.cancel_hardware')
-    @patch('SoftLayer.CLI.modules.server.resolve_id')
-    def test_CancelServer(
-            self, resolve_mock, cancel_mock, ngb_mock, abort_mock):
+    @mock.patch('SoftLayer.CLI.formatting.no_going_back')
+    @mock.patch('SoftLayer.HardwareManager.cancel_hardware')
+    @mock.patch('SoftLayer.CLI.helpers.resolve_id')
+    def test_cancel_server(self, resolve_mock, cancel_mock, ngb_mock):
         hw_id = 12345
         resolve_mock.return_value = hw_id
         ngb_mock.return_value = False
@@ -315,19 +328,18 @@ class ServerCLITests(unittest.TestCase):
         cancel_mock.assert_called_with(hw_id, args['--reason'], None)
 
         # Now check to make sure we properly call CLIAbort in the negative case
-        env_mock = Mock()
-        env_mock.input = Mock()
+        env_mock = mock.Mock()
+        env_mock.input = mock.Mock()
         env_mock.input.return_value = 'Comment'
 
         args['--really'] = False
         runnable = server.CancelServer(client=self.client, env=env_mock)
 
-        runnable.execute(args)
-        abort_mock.assert_called()
+        self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
         env_mock.assert_called()
 
-    @patch('SoftLayer.CLI.modules.server.confirm')
-    def test_ServerPowerOff(self, confirm_mock):
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_server_power_off(self, confirm_mock):
         hw_id = 12345
         runnable = server.ServerPowerOff(client=self.client)
 
@@ -341,10 +353,10 @@ class ServerCLITests(unittest.TestCase):
         # Now check to make sure we properly call CLIAbort in the negative case
         confirm_mock.return_value = False
         args['--really'] = False
-        self.assertRaises(CLIAbort, runnable.execute, args)
+        self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
-    @patch('SoftLayer.CLI.modules.server.confirm')
-    def test_ServerReboot(self, confirm_mock):
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_server_reboot(self, confirm_mock):
         hw_id = 12345
         runnable = server.ServerReboot(client=self.client)
 
@@ -373,9 +385,9 @@ class ServerCLITests(unittest.TestCase):
         # Now check to make sure we properly call CLIAbort in the negative case
         confirm_mock.return_value = False
         args['--really'] = False
-        self.assertRaises(CLIAbort, runnable.execute, args)
+        self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
-    def test_ServerPowerOn(self):
+    def test_server_power_on(self):
         hw_id = 12345
         runnable = server.ServerPowerOn(client=self.client)
 
@@ -387,8 +399,8 @@ class ServerCLITests(unittest.TestCase):
         runnable.execute(args)
         self.client['Hardware_Server'].powerOn.assert_called_with(id=hw_id)
 
-    @patch('SoftLayer.CLI.modules.server.confirm')
-    def test_ServerPowerCycle(self, confirm_mock):
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_server_power_cycle(self, confirm_mock):
         hw_id = 12345
         runnable = server.ServerPowerCycle(client=self.client)
 
@@ -404,11 +416,11 @@ class ServerCLITests(unittest.TestCase):
         # Now check to make sure we properly call CLIAbort in the negative case
         confirm_mock.return_value = False
         args['--really'] = False
-        self.assertRaises(CLIAbort, runnable.execute, args)
+        self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
-    @patch('SoftLayer.HardwareManager.change_port_speed')
-    @patch('SoftLayer.CLI.modules.server.resolve_id')
-    def test_NicEditServer(self, resolve_mock, port_mock):
+    @mock.patch('SoftLayer.HardwareManager.change_port_speed')
+    @mock.patch('SoftLayer.CLI.helpers.resolve_id')
+    def test_cic_edit_server(self, resolve_mock, port_mock):
         hw_id = 12345
         resolve_mock.return_value = hw_id
 
@@ -430,8 +442,9 @@ class ServerCLITests(unittest.TestCase):
         # Second call simulates an error
         runnable.execute(args)
 
-    @patch('SoftLayer.HardwareManager.get_available_dedicated_server_packages')
-    def test_ListChassisServer(self, packages):
+    @mock.patch('SoftLayer.HardwareManager'
+                '.get_available_dedicated_server_packages')
+    def test_list_chassis_server(self, packages):
         test_data = [
             (1, 'Chassis 1'),
             (2, 'Chassis 2')
@@ -446,9 +459,9 @@ class ServerCLITests(unittest.TestCase):
             {'Chassis': 'Chassis 2', 'Code': 2}
         ]
 
-        self.assertEqual(expected, format_output(output, 'python'))
+        self.assertEqual(expected, formatting.format_output(output, 'python'))
 
-    def test_CreateServer(self):
+    def test_create_server(self):
         args = {
             '--chassis': 999,
             '--hostname': 'test',
@@ -472,7 +485,8 @@ class ServerCLITests(unittest.TestCase):
         runnable = server.CreateServer(client=self.client)
 
         # First, test the --test flag
-        with patch('SoftLayer.HardwareManager.verify_order') as verify_mock:
+        with mock.patch('SoftLayer.HardwareManager'
+                        '.verify_order') as verify_mock:
             verify_mock.return_value = {
                 'prices': [
                     {
@@ -498,33 +512,27 @@ class ServerCLITests(unittest.TestCase):
                 ''
             ]
 
-            self.assertEqual(expected, format_output(output, 'python'))
+            self.assertEqual(expected,
+                             formatting.format_output(output, 'python'))
 
             # Make sure we can order without specifying the disk as well
             args['--disk'] = []
 
             output = runnable.execute(args)
 
-            self.assertEqual(expected, format_output(output, 'python'))
-
-            # And make sure we can pass in disk and SSH keys as comma separated
-            # strings, which is what templates do
-            args['--disk'] = '1000_DRIVE,1000_DRIVE'
-            args['--key'] = '123,456'
-
-            output = runnable.execute(args)
-
-            self.assertEqual(expected, format_output(output, 'python'))
+            self.assertEqual(expected,
+                             formatting.format_output(output, 'python'))
 
             # Test explicitly setting a RAID configuration
             args['--controller'] = 'RAID0'
 
             output = runnable.execute(args)
 
-            self.assertEqual(expected, format_output(output, 'python'))
+            self.assertEqual(expected,
+                             formatting.format_output(output, 'python'))
 
         # Now test ordering
-        with patch('SoftLayer.HardwareManager.place_order') as order_mock:
+        with mock.patch('SoftLayer.HardwareManager.place_order') as order_mock:
             order_mock.return_value = {
                 'orderId': 98765,
                 'orderDate': '2013-08-02 15:23:47'
@@ -536,17 +544,18 @@ class ServerCLITests(unittest.TestCase):
             output = runnable.execute(args)
 
             expected = {'id': 98765, 'created': '2013-08-02 15:23:47'}
-            self.assertEqual(expected, format_output(output, 'python'))
+            self.assertEqual(expected,
+                             formatting.format_output(output, 'python'))
 
         # Finally, test cancelling the process
-        with patch('SoftLayer.CLI.modules.server.confirm') as confirm:
+        with mock.patch('SoftLayer.CLI.formatting.confirm') as confirm:
             confirm.return_value = False
 
             args['--really'] = False
 
-            self.assertRaises(CLIAbort, runnable.execute, args)
+            self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
-    def test_CreateServer_failures(self):
+    def test_create_server_failures(self):
 
         # This is missing a required argument
         args = {
@@ -566,24 +575,24 @@ class ServerCLITests(unittest.TestCase):
         runnable = server.CreateServer(client=self.client)
 
         # Verify that ArgumentError is properly raised on error
-        self.assertRaises(ArgumentError, runnable.execute, args)
+        self.assertRaises(exceptions.ArgumentError, runnable.execute, args)
 
         # This contains an invalid network argument
         args['--chassis'] = 999
         args['--network'] = 9999
 
         # Verify that CLIAbort is properly raised on error
-        self.assertRaises(CLIAbort, runnable.execute, args)
+        self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
         # This contains an invalid operating system argument
         args['--network'] = '100'
         args['--os'] = 'nope'
 
         # Verify that CLIAbort is properly raised on error
-        self.assertRaises(CLIAbort, runnable.execute, args)
+        self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
-    @patch('SoftLayer.CLI.modules.server.export_to_template')
-    def test_CreateServer_with_export(self, export_to_template):
+    @mock.patch('SoftLayer.CLI.template.export_to_template')
+    def test_create_server_with_export(self, export_to_template):
         args = {
             '--chassis': 999,
             '--hostname': 'test',
@@ -611,9 +620,10 @@ class ServerCLITests(unittest.TestCase):
         export_to_template.assert_called_with('test_file.txt', expected,
                                               exclude=['--wait', '--test'])
 
-    @patch('SoftLayer.HardwareManager.get_available_dedicated_server_packages')
-    @patch('SoftLayer.HardwareManager.get_bare_metal_package_id')
-    def test_CreateServer_for_bmc(self, bmpi, packages):
+    @mock.patch('SoftLayer.HardwareManager'
+                '.get_available_dedicated_server_packages')
+    @mock.patch('SoftLayer.HardwareManager.get_bare_metal_package_id')
+    def test_create_server_for_bmc(self, bmpi, packages):
         args = {
             '--chassis': '1099',
             '--hostname': 'test',
@@ -644,7 +654,8 @@ class ServerCLITests(unittest.TestCase):
         runnable = server.CreateServer(client=self.client)
 
         # First, test the --test flag
-        with patch('SoftLayer.HardwareManager.verify_order') as verify_mock:
+        with mock.patch('SoftLayer.HardwareManager'
+                        '.verify_order') as verify_mock:
             verify_mock.return_value = {
                 'prices': [
                     {
@@ -670,33 +681,27 @@ class ServerCLITests(unittest.TestCase):
                 ''
             ]
 
-            self.assertEqual(expected, format_output(output, 'python'))
+            self.assertEqual(expected,
+                             formatting.format_output(output, 'python'))
 
             # Make sure we can order without specifying the disk as well
             args['--disk'] = []
 
             output = runnable.execute(args)
 
-            self.assertEqual(expected, format_output(output, 'python'))
-
-            # And make sure we can pass in disk and SSH keys as comma separated
-            # strings, which is what templates do
-            args['--disk'] = '1000_DRIVE,1000_DRIVE'
-            args['--key'] = '123,456'
-
-            output = runnable.execute(args)
-
-            self.assertEqual(expected, format_output(output, 'python'))
+            self.assertEqual(expected,
+                             formatting.format_output(output, 'python'))
 
             # Test explicitly setting a RAID configuration
             args['--controller'] = 'RAID0'
 
             output = runnable.execute(args)
 
-            self.assertEqual(expected, format_output(output, 'python'))
+            self.assertEqual(expected,
+                             formatting.format_output(output, 'python'))
 
         # Now test ordering
-        with patch('SoftLayer.HardwareManager.place_order') as order_mock:
+        with mock.patch('SoftLayer.HardwareManager.place_order') as order_mock:
             order_mock.return_value = {
                 'orderId': 98765,
                 'orderDate': '2013-08-02 15:23:47'
@@ -708,17 +713,18 @@ class ServerCLITests(unittest.TestCase):
             output = runnable.execute(args)
 
             expected = {'id': 98765, 'created': '2013-08-02 15:23:47'}
-            self.assertEqual(expected, format_output(output, 'python'))
+            self.assertEqual(expected,
+                             formatting.format_output(output, 'python'))
 
         # Finally, test cancelling the process
-        with patch('SoftLayer.CLI.modules.server.confirm') as confirm:
+        with mock.patch('SoftLayer.CLI.formatting.confirm') as confirm:
             confirm.return_value = False
 
             args['--really'] = False
 
-            self.assertRaises(CLIAbort, runnable.execute, args)
+            self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
-    def test_EditServer(self):
+    def test_edit_server(self):
         # Test both userdata and userfile at once
         args = {
             '<identifier>': 1000,
@@ -729,15 +735,15 @@ class ServerCLITests(unittest.TestCase):
         }
         runnable = server.EditServer(client=self.client)
 
-        self.assertRaises(ArgumentError, runnable.execute, args)
+        self.assertRaises(exceptions.ArgumentError, runnable.execute, args)
 
         # Simulate a missing file error
         args['--userdata'] = None
 
-        with patch('os.path.exists') as exists:
+        with mock.patch('os.path.exists') as exists:
             exists.return_value = False
 
-            self.assertRaises(ArgumentError, runnable.execute, args)
+            self.assertRaises(exceptions.ArgumentError, runnable.execute, args)
 
         # Test a successful edit with user data
         args['--userdata'] = 'My data'
@@ -749,7 +755,7 @@ class ServerCLITests(unittest.TestCase):
             'hostname': 'hardware-test1',
         }
 
-        with patch('SoftLayer.HardwareManager.edit') as edit_mock:
+        with mock.patch('SoftLayer.HardwareManager.edit') as edit_mock:
             edit_mock.return_value = True
 
             runnable.execute(args)
@@ -759,7 +765,7 @@ class ServerCLITests(unittest.TestCase):
             # Now check for a CLIAbort if there's an error
             edit_mock.return_value = False
 
-            self.assertRaises(CLIAbort, runnable.execute, args)
+            self.assertRaises(exceptions.CLIAbort, runnable.execute, args)
 
         # Test a successful edit with a user file
         args['--userdata'] = None
@@ -771,14 +777,14 @@ class ServerCLITests(unittest.TestCase):
             'hostname': 'hardware-test1',
         }
 
-        with patch('os.path.exists') as exists:
+        with mock.patch('os.path.exists') as exists:
             exists.return_value = True
-            with patch(builtins_name + '.open') as file_mock:
+            with mock.patch(builtins_name + '.open') as file_mock:
                 file_mock.return_value.__enter__ = lambda s: s
-                file_mock.return_value.__exit__ = Mock()
+                file_mock.return_value.__exit__ = mock.Mock()
                 file_mock.return_value.read.return_value = 'some data'
 
-                with patch('SoftLayer.HardwareManager.edit') as edit_mock:
+                with mock.patch('SoftLayer.HardwareManager.edit') as edit_mock:
                     edit_mock.return_value = True
                     expected['userdata'] = 'some data'
 
