@@ -4,21 +4,22 @@
 
     :license: MIT, see LICENSE for more details.
 """
-from SoftLayer import VSManager
-from SoftLayer.tests import unittest, FixtureClient
-from SoftLayer.tests.fixtures import Virtual_Guest
+import mock
 
-from mock import MagicMock, ANY, call, patch
+import SoftLayer
+from SoftLayer import testing
+from SoftLayer.testing import fixtures
 
 
-class VSTests(unittest.TestCase):
+class VSTests(testing.TestCase):
 
-    def setUp(self):
-        self.client = FixtureClient()
-        self.vs = VSManager(self.client)
+    def set_up(self):
+        self.client = testing.FixtureClient()
+        self.vs = SoftLayer.VSManager(self.client,
+                                      SoftLayer.OrderingManager(self.client))
 
     def test_list_instances(self):
-        mcall = call(mask=ANY, filter={})
+        mcall = mock.call(mask=mock.ANY, filter={})
         service = self.client['Account']
 
         list_expected_ids = [100, 104]
@@ -62,7 +63,7 @@ class VSTests(unittest.TestCase):
         )
 
         service = self.client['Account']
-        service.getVirtualGuests.assert_has_calls(call(
+        service.getVirtualGuests.assert_has_calls(mock.call(
             filter={
                 'virtualGuests': {
                     'datacenter': {
@@ -81,7 +82,7 @@ class VSTests(unittest.TestCase):
                     'primaryIpAddress': {'operation': '_= 1.2.3.4'},
                     'primaryBackendIpAddress': {'operation': '_= 4.3.2.1'}
                 }},
-            mask=ANY,
+            mask=mock.ANY,
         ))
 
     def test_resolve_ids_ip(self):
@@ -104,12 +105,13 @@ class VSTests(unittest.TestCase):
     def test_get_instance(self):
         result = self.vs.get_instance(100)
         self.client['Virtual_Guest'].getObject.assert_called_once_with(
-            id=100, mask=ANY)
-        self.assertEqual(Virtual_Guest.getObject, result)
+            id=100, mask=mock.ANY)
+        self.assertEqual(fixtures.Virtual_Guest.getObject, result)
 
     def test_get_create_options(self):
         results = self.vs.get_create_options()
-        self.assertEqual(Virtual_Guest.getCreateObjectOptions, results)
+        self.assertEqual(fixtures.Virtual_Guest.getCreateObjectOptions,
+                         results)
 
     def test_cancel_instance(self):
         self.vs.cancel_instance(1)
@@ -124,7 +126,7 @@ class VSTests(unittest.TestCase):
                                   {'customProvisionScriptUri': post_uri,
                                    'sshKeyIds': [1701]}, id=1)
 
-    @patch('SoftLayer.managers.vs.VSManager._generate_create_dict')
+    @mock.patch('SoftLayer.managers.vs.VSManager._generate_create_dict')
     def test_create_verify(self, create_dict):
         create_dict.return_value = {'test': 1, 'verify': 1}
         self.vs.verify_create_instance(test=1, verify=1)
@@ -132,7 +134,7 @@ class VSTests(unittest.TestCase):
         f = self.client['Virtual_Guest'].generateOrderTemplate
         f.assert_called_once_with({'test': 1, 'verify': 1})
 
-    @patch('SoftLayer.managers.vs.VSManager._generate_create_dict')
+    @mock.patch('SoftLayer.managers.vs.VSManager._generate_create_dict')
     def test_create_instance(self, create_dict):
         create_dict.return_value = {'test': 1, 'verify': 1}
         self.vs.create_instance(test=1, verify=1)
@@ -140,6 +142,19 @@ class VSTests(unittest.TestCase):
         self.client['Virtual_Guest'].createObject.assert_called_once_with(
             {'test': 1, 'verify': 1})
 
+    def test_create_instances(self):
+        self.vs.create_instances([{'cpus': 1,
+                                   'memory': 1024,
+                                   'hostname': 'server',
+                                   'domain': 'example.com'}])
+        self.client['Virtual_Guest'].createObjects.assert_called_once_with([
+            {'domain': 'example.com',
+             'hourlyBillingFlag': True,
+             'localDiskFlag': True,
+             'maxMemory': 1024, 'hostname':
+             'server',
+             'startCpus': 1}])
+
     def test_generate_os_and_image(self):
         self.assertRaises(
             ValueError,
@@ -534,11 +549,17 @@ class VSTests(unittest.TestCase):
 
     def test_upgrade(self):
         # Testing  Upgrade
-        orderClient = self.client['Product_Order']
+        order_client = self.client['Product_Order']
+
+        self.client['Product_Package'].getAllObjects.return_value = [
+            {'id': 46, 'name': 'Virtual Servers',
+             'description': 'Virtual Server Instances',
+             'type': {'keyName': 'VIRTUAL_SERVER_INSTANCE'}, 'isActive': 1},
+        ]
 
         # test single upgrade
         self.vs.upgrade(1, cpus=4, public=False)
-        orderClient.placeOrder.called_once_with(1, cpus=4, public=False)
+        order_client.placeOrder.called_once_with(1, cpus=4, public=False)
 
         # Now test a blank upgrade
         self.vs.upgrade(1)
@@ -547,7 +568,7 @@ class VSTests(unittest.TestCase):
         # Testing all parameters Upgrade
         self.vs.upgrade(1, cpus=4, memory=2, nic_speed=1000, public=True)
         args = {'cpus': 4, 'memory': 2, 'nic_speed': 1000, 'public': 1000}
-        orderClient.placeOrder.called_once_with(1, **args)
+        order_client.placeOrder.called_once_with(1, **args)
 
     def test_get_item_id_for_upgrade(self):
         item_id = 0
@@ -560,14 +581,14 @@ class VSTests(unittest.TestCase):
         self.assertEqual(1133, item_id)
 
 
-class VSWaitReadyGoTests(unittest.TestCase):
+class VSWaitReadyGoTests(testing.TestCase):
 
-    def setUp(self):
-        self.client = MagicMock()
-        self.vs = VSManager(self.client)
+    def set_up(self):
+        self.client = mock.MagicMock()
+        self.vs = SoftLayer.VSManager(self.client)
         self.guestObject = self.client['Virtual_Guest'].getObject
 
-    @patch('SoftLayer.managers.vs.VSManager.wait_for_ready')
+    @mock.patch('SoftLayer.managers.vs.VSManager.wait_for_ready')
     def test_wait_interface(self, ready):
         # verify interface to wait_for_ready is intact
         self.vs.wait_for_transaction(1, 1)
@@ -636,7 +657,7 @@ class VSWaitReadyGoTests(unittest.TestCase):
         value = self.vs.wait_for_ready(1, 1, pending=True)
         self.assertFalse(value)
 
-    @patch('SoftLayer.managers.vs.sleep')
+    @mock.patch('time.sleep')
     def test_ready_iter_once_incomplete(self, _sleep):
         self.guestObject = self.client['Virtual_Guest'].getObject
 
@@ -648,7 +669,7 @@ class VSWaitReadyGoTests(unittest.TestCase):
         self.assertFalse(value)
         self.assertFalse(_sleep.called)
 
-    @patch('SoftLayer.managers.vs.sleep')
+    @mock.patch('time.sleep')
     def test_iter_once_complete(self, _sleep):
         # no iteration, true
         self.guestObject.side_effect = [
@@ -658,7 +679,7 @@ class VSWaitReadyGoTests(unittest.TestCase):
         self.assertTrue(value)
         self.assertFalse(_sleep.called)
 
-    @patch('SoftLayer.managers.vs.sleep')
+    @mock.patch('time.sleep')
     def test_iter_four_complete(self, _sleep):
         # test 4 iterations with positive match
         self.guestObject.side_effect = [
@@ -670,13 +691,13 @@ class VSWaitReadyGoTests(unittest.TestCase):
 
         value = self.vs.wait_for_ready(1, 4)
         self.assertTrue(value)
-        _sleep.assert_has_calls([call(1), call(1), call(1)])
+        _sleep.assert_has_calls([mock.call(1), mock.call(1), mock.call(1)])
         self.guestObject.assert_has_calls([
-            call(id=1, mask=ANY), call(id=1, mask=ANY),
-            call(id=1, mask=ANY), call(id=1, mask=ANY),
+            mock.call(id=1, mask=mock.ANY), mock.call(id=1, mask=mock.ANY),
+            mock.call(id=1, mask=mock.ANY), mock.call(id=1, mask=mock.ANY),
         ])
 
-    @patch('SoftLayer.managers.vs.sleep')
+    @mock.patch('time.sleep')
     def test_iter_two_incomplete(self, _sleep):
         # test 2 iterations, with no matches
         self.guestObject.side_effect = [
@@ -688,10 +709,10 @@ class VSWaitReadyGoTests(unittest.TestCase):
         self.assertFalse(value)
         _sleep.assert_called_once_with(1)
         self.guestObject.assert_has_calls([
-            call(id=1, mask=ANY), call(id=1, mask=ANY),
+            mock.call(id=1, mask=mock.ANY), mock.call(id=1, mask=mock.ANY),
         ])
 
-    @patch('SoftLayer.managers.vs.sleep')
+    @mock.patch('time.sleep')
     def test_iter_ten_incomplete(self, _sleep):
         # 10 iterations at 10 second sleeps with no
         # matching values.
@@ -710,14 +731,15 @@ class VSWaitReadyGoTests(unittest.TestCase):
         value = self.vs.wait_for_ready(1, 10, delay=10)
         self.assertFalse(value)
         self.guestObject.assert_has_calls([
-            call(id=1, mask=ANY), call(id=1, mask=ANY),
-            call(id=1, mask=ANY), call(id=1, mask=ANY),
-            call(id=1, mask=ANY), call(id=1, mask=ANY),
-            call(id=1, mask=ANY), call(id=1, mask=ANY),
-            call(id=1, mask=ANY), call(id=1, mask=ANY),
+            mock.call(id=1, mask=mock.ANY), mock.call(id=1, mask=mock.ANY),
+            mock.call(id=1, mask=mock.ANY), mock.call(id=1, mask=mock.ANY),
+            mock.call(id=1, mask=mock.ANY), mock.call(id=1, mask=mock.ANY),
+            mock.call(id=1, mask=mock.ANY), mock.call(id=1, mask=mock.ANY),
+            mock.call(id=1, mask=mock.ANY), mock.call(id=1, mask=mock.ANY),
         ])
         # should only be 9 calls to sleep, last iteration
         # should return a value and skip the sleep
         _sleep.assert_has_calls([
-            call(10), call(10), call(10), call(10), call(10),
-            call(10), call(10), call(10), call(10)])
+            mock.call(10), mock.call(10), mock.call(10), mock.call(10),
+            mock.call(10), mock.call(10), mock.call(10), mock.call(10),
+            mock.call(10)])
